@@ -3,7 +3,7 @@ import pathlib
 
 import pytest
 
-from simpleindex.configs import _Route, _RouteSource, parse
+from simpleindex.configs import _Route, parse
 from simpleindex.routes import HTTPRoute, PathRoute
 
 
@@ -13,15 +13,15 @@ def test_configuration_parse(tmp_path):
     assert conf.server == {"host": "127.0.0.1", "port": 8000}
     assert conf.routes == {
         "my-first-package": _Route(
-            source=_RouteSource.path,
+            source="path",
             to="./index/my-first-package",
         ),
         "my-second-package": _Route(
-            source=_RouteSource.path,
+            source="path",
             to="./index/my-second-package/index.html",
         ),
         "{project}": _Route(
-            source=_RouteSource.http,
+            source="http",
             to="https://pypi.org/simple/{project}/",
         ),
     }
@@ -31,14 +31,11 @@ def test_configuration_parse(tmp_path):
     "conf, result",
     [
         (
-            _Route(source=_RouteSource.path, to="./index/my-first-package"),
+            _Route(source="path", to="./index/my-first-package"),
             PathRoute(root=pathlib.Path(), to="./index/my-first-package"),
         ),
         (
-            _Route(
-                source=_RouteSource.http,
-                to="https://pypi.org/simple/{project}/",
-            ),
+            _Route(source="http", to="https://pypi.org/simple/{project}/"),
             HTTPRoute(
                 root=pathlib.Path(),
                 to="https://pypi.org/simple/{project}/",
